@@ -1,7 +1,7 @@
 
 /*
  *  Diverse Bristol audio routines.
- *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2011
+ *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2012
  *
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -37,6 +37,8 @@
 
 #include "brightonKeyboards.h"
 
+#include "brightonVImages.h"
+
 extern brightonApp miniApp;
 extern brightonApp prophetApp;
 extern brightonApp hammondApp;
@@ -381,7 +383,9 @@ main(int argc, char **argv)
 		}
 	}
 
-	if ((strcmp(argv[argCount], "-V") == 0) && (strlen(argv[argCount]) == 2))
+	if (((strcmp(argv[argCount], "-V") == 0)
+		|| (strcmp(argv[argCount], "-version") == 0))
+		&& (strlen(argv[argCount]) == 2))
 	{
 		printf("Version %s\n", VERSION);
 		exit(0);
