@@ -1,7 +1,7 @@
 
 /*
  *  Diverse Bristol audio routines.
- *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2011
+ *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2012
  *
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -51,6 +51,31 @@ extern guimain global;
 #define CDIFF 32
 #define CDIFF2 12
 
+#define PC0 118
+#define PC1 (PC0 + CDIFF)
+#define PC2 (PC1 + CDIFF)
+#define PC3 (PC2 + CDIFF)
+#define PC4 (PC3 + CDIFF)
+#define PC5 (PC4 + CDIFF)
+#define PC6 (PC5 + CDIFF + CDIFF2)
+#define PC7 (PC6 + CDIFF)
+#define PC8 (PC7 + CDIFF)
+#define PC9 (PC8 + CDIFF + CDIFF2)
+#define PC10 (PC9 + CDIFF + CDIFF2)
+#define PC11 (PC10 + CDIFF)
+#define PC12 (PC11 + CDIFF)
+#define PC13 (PC12 + CDIFF + CDIFF2)
+#define PC14 (PC13 + CDIFF)
+#define PC15 (PC14 + CDIFF + CDIFF2)
+#define PC16 (PC15 + CDIFF)
+#define PC17 (PC16 + CDIFF)
+#define PC18 (PC17 + CDIFF + CDIFF2)
+#define PC19 (PC18 + CDIFF)
+#define PC20 (PC19 + CDIFF + CDIFF2)
+#define PC21 (PC20 + CDIFF)
+#define PC22 (PC21 + CDIFF)
+#define PC23 (PC22 + CDIFF)
+
 #define C0 126
 #define C1 (C0 + CDIFF)
 #define C2 (C1 + CDIFF)
@@ -76,13 +101,20 @@ extern guimain global;
 #define C22 (C21 + CDIFF)
 #define C23 (C22 + CDIFF)
 
+#define RP0 414
+#define RP1 (RP0 + 205)
+#define RP2 (RP0 + 100)
+#define RP3 880
+
 #define R0 500
 #define R1 (R0 + 205)
 #define R2 (R0 + 75)
 #define R3 900
 
 #define W1 12
+#define PW1 26
 #define L1 300
+#define LP1 363
 
 #define BDIFF (CDIFF + 2)
 #define BDIFF2 (CDIFF2 + 2)
@@ -127,6 +159,136 @@ extern guimain global;
  *
  * This example is for a axxeBristol type synth interface.
  */
+static brightonLocations phatlocations[DEVICE_COUNT] = {
+	/* Glide/Tranpose - 0 */
+	{"Glide", 1, PC0, RP0, PW1, LP1, 0, 1, 0,
+		"bitmaps/knobs/sliderblack.xpm", 0, 0},
+	{"Transpose", 2, C1, R2 - 30, 15, LP1/2 - 60, 0, 2, 0, 0, 0,
+		BRIGHTON_THREEWAY|BRIGHTON_NOSHADOW},
+
+	/* VCO - 2 */
+	{"VCO LFO Sine Mod", 1, PC2, RP0, PW1, LP1, 0, 1, 0,
+		"bitmaps/knobs/sliderblack.xpm", 0, 0},
+	{"VCO LFO Square Mod", 1, PC3, RP0, PW1, LP1, 0, 1, 0,
+		"bitmaps/knobs/sliderblack.xpm", 0, 0},
+	{"VCO S/H Mod", 1, PC4, RP0, PW1, LP1, 0, 1, 0,
+		"bitmaps/knobs/sliderblack.xpm", 0, 0},
+	{"VCO ADSR Mod", 1, PC5, RP0, PW1, LP1, 0, 1, 0,
+		"bitmaps/knobs/sliderblack.xpm", 0, 0},
+	{"VCO PW", 1, PC6, RP0, PW1, LP1, 0, 1, 0,
+		"bitmaps/knobs/sliderblack.xpm", 0, 0},
+	{"VCO PWM LFO", 1, PC7, RP0, PW1, LP1, 0, 1, 0,
+		"bitmaps/knobs/sliderblack.xpm", 0, 0},
+	{"VCO PWM ADSR", 1, PC8, RP0, PW1, LP1, 0, 1, 0,
+		"bitmaps/knobs/sliderblack.xpm", 0, 0},
+
+	/* LFO - 9 */
+	{"LFO Freq", 1, PC9, RP0, PW1, LP1, 0, 1, 0,
+		"bitmaps/knobs/sliderblack.xpm", 0, 0},
+
+	/* Mixer - 10 */
+	{"Mix Noise", 1, PC10, RP0, PW1, LP1, 0, 1, 0,
+		"bitmaps/knobs/sliderblack.xpm", 0, 0},
+	{"Mix VCO Ramp", 1, PC11, RP0, PW1, LP1, 0, 1, 0,
+		"bitmaps/knobs/sliderblack.xpm", 0, 0},
+	{"Mix VCO Pulse", 1, PC12, RP0, PW1, LP1, 0, 1, 0,
+		"bitmaps/knobs/sliderblack.xpm", 0, 0},
+
+	/* VCF - 13 */
+	{"VCF Cutoff", 1, PC13, RP0, PW1, LP1, 0, 1, 0,
+		"bitmaps/knobs/sliderblack.xpm", 0, 0},
+	{"VCO Resonance", 1, PC14, RP0, PW1, LP1, 0, 1, 0,
+		"bitmaps/knobs/sliderblack.xpm", 0, 0},
+	{"VCO KBD", 1, PC15, RP0, PW1, LP1, 0, 1, 0,
+		"bitmaps/knobs/sliderblack.xpm", 0, 0},
+	{"VCF LFO Sine", 1, PC16, RP0, PW1, LP1, 0, 1, 0,
+		"bitmaps/knobs/sliderblack.xpm", 0, 0},
+	{"VCF ADSR", 1, PC17, RP0, PW1, LP1, 0, 1, 0,
+		"bitmaps/knobs/sliderblack.xpm", 0, 0},
+
+	/* VCA - 18 */
+	{"VCA Gain", 1, PC18, RP0, PW1, LP1, 0, 1, 0,
+		"bitmaps/knobs/sliderblack.xpm", 0, 0},
+	{"VCA ADSR", 1, PC19, RP0, PW1, LP1, 0, 1, 0,
+		"bitmaps/knobs/sliderblack.xpm", 0, 0},
+
+	/* ADSR - 20 */
+	{"Attack", 1, PC20, RP0, PW1, LP1, 0, 1, 0,
+		"bitmaps/knobs/sliderblack.xpm", 0, 0},
+	{"Decay", 1, PC21, RP0, PW1, LP1, 0, 1, 0,
+		"bitmaps/knobs/sliderblack.xpm", 0, 0},
+	{"Sustain", 1, PC22, RP0, PW1, LP1, 0, 1, 0,
+		"bitmaps/knobs/sliderblack.xpm", 0, 0},
+	{"Release", 1, PC23, RP0, PW1, LP1, 0, 1, 0,
+		"bitmaps/knobs/sliderblack.xpm", 0, 0},
+
+	/* Pink/White noise - 24 */
+	{"Pink/White", 2, C1, 110, 14, 100, 0, 1, 0,
+		"bitmaps/buttons/klunk.xpm", 0, BRIGHTON_VERTICAL},
+
+	/* LFO mode - 25 */
+	{"LFO S/M", 2, C22, 110, 14, 100, 0, 1, 0,
+		"bitmaps/buttons/klunk.xpm", 0, BRIGHTON_VERTICAL},
+
+	/* LFO trigger - gate/auto - 26 */
+	{"LFO Trig", 2, C20, 110, 14, 100, 0, 1, 0,
+		"bitmaps/buttons/klunk.xpm", 0, BRIGHTON_VERTICAL},
+
+	/* Pitch Control - 27 */
+	{"Pitch Flat", 2, 25, RP2, 30, 80, 0, 1, 0, "bitmaps/buttons/touchnlw.xpm",
+		"bitmaps/buttons/touchnlw.xpm", 0},
+	{"Pitch Trill", 2, 53, RP2, 30, 80, 0, 1, 0, "bitmaps/buttons/touchnlw.xpm",
+		"bitmaps/buttons/touchnlw.xpm", 0},
+	{"Pitch Sharp", 2, 80, RP2, 30, 80, 0, 1, 0, "bitmaps/buttons/touchnlw.xpm",
+		"bitmaps/buttons/touchnlw.xpm", 0},
+
+	/* Memory Load, mem, Save - 30 */
+	{"", 2, B0, RP3, 20, 60, 0, 1, 0, "bitmaps/buttons/pressoffw.xpm",
+		"bitmaps/buttons/pressonw.xpm", BRIGHTON_CHECKBUTTON},
+
+	{"", 2, B1, RP3, 20, 60, 0, 1, 0, "bitmaps/buttons/pressoffg.xpm",
+		"bitmaps/buttons/pressong.xpm", BRIGHTON_RADIOBUTTON},
+	{"", 2, B2, RP3, 20, 60, 0, 1, 0, "bitmaps/buttons/pressoffg.xpm",
+		"bitmaps/buttons/pressong.xpm", BRIGHTON_RADIOBUTTON},
+	{"", 2, B3, RP3, 20, 60, 0, 1, 0, "bitmaps/buttons/pressoffg.xpm",
+		"bitmaps/buttons/pressong.xpm", BRIGHTON_RADIOBUTTON},
+	{"", 2, B4, RP3, 20, 60, 0, 1, 0, "bitmaps/buttons/pressoffg.xpm",
+		"bitmaps/buttons/pressong.xpm", BRIGHTON_RADIOBUTTON},
+	{"", 2, B5, RP3, 20, 60, 0, 1, 0, "bitmaps/buttons/pressoffg.xpm",
+		"bitmaps/buttons/pressong.xpm", BRIGHTON_RADIOBUTTON},
+	{"", 2, B6, RP3, 20, 60, 0, 1, 0, "bitmaps/buttons/pressoffg.xpm",
+		"bitmaps/buttons/pressong.xpm", BRIGHTON_RADIOBUTTON},
+	{"", 2, B7, RP3, 20, 60, 0, 1, 0, "bitmaps/buttons/pressoffg.xpm",
+		"bitmaps/buttons/pressong.xpm", BRIGHTON_RADIOBUTTON},
+	{"", 2, B8, RP3, 20, 60, 0, 1, 0, "bitmaps/buttons/pressoffg.xpm",
+		"bitmaps/buttons/pressong.xpm", BRIGHTON_RADIOBUTTON},
+
+	{"", 2, B9, RP3, 20, 60, 0, 1, 0, "bitmaps/buttons/pressoffg.xpm",
+		"bitmaps/buttons/pressong.xpm", BRIGHTON_RADIOBUTTON},
+	{"", 2, B10, RP3, 20, 60, 0, 1, 0, "bitmaps/buttons/pressoffg.xpm",
+		"bitmaps/buttons/pressong.xpm", BRIGHTON_RADIOBUTTON},
+	{"", 2, B11, RP3, 20, 60, 0, 1, 0, "bitmaps/buttons/pressoffg.xpm",
+		"bitmaps/buttons/pressong.xpm", BRIGHTON_RADIOBUTTON},
+	{"", 2, B12, RP3, 20, 60, 0, 1, 0, "bitmaps/buttons/pressoffg.xpm",
+		"bitmaps/buttons/pressong.xpm", BRIGHTON_RADIOBUTTON},
+	{"", 2, B13, RP3, 20, 60, 0, 1, 0, "bitmaps/buttons/pressoffg.xpm",
+		"bitmaps/buttons/pressong.xpm", BRIGHTON_RADIOBUTTON},
+	{"", 2, B14, RP3, 20, 60, 0, 1, 0, "bitmaps/buttons/pressoffg.xpm",
+		"bitmaps/buttons/pressong.xpm", BRIGHTON_RADIOBUTTON},
+	{"", 2, B15, RP3, 20, 60, 0, 1, 0, "bitmaps/buttons/pressoffg.xpm",
+		"bitmaps/buttons/pressong.xpm", BRIGHTON_RADIOBUTTON},
+	{"", 2, B16, RP3, 20, 60, 0, 1, 0, "bitmaps/buttons/pressoffg.xpm",
+		"bitmaps/buttons/pressong.xpm", BRIGHTON_RADIOBUTTON},
+
+	{"", 2, B17, RP3, 20, 60, 0, 1, 0, "bitmaps/buttons/pressoffo.xpm",
+		"bitmaps/buttons/pressono.xpm", BRIGHTON_CHECKBUTTON},
+
+	/* MIDI - or android up/down memories */
+	{"", 2, B18, RP3, 20, 60, 0, 1, 0, "bitmaps/buttons/pressoffw.xpm",
+		"bitmaps/buttons/pressonw.xpm", BRIGHTON_CHECKBUTTON},
+	{"", 2, B19, RP3, 20, 60, 0, 1, 0, "bitmaps/buttons/pressoffw.xpm",
+		"bitmaps/buttons/pressonw.xpm", BRIGHTON_CHECKBUTTON},
+};
 static brightonLocations locations[DEVICE_COUNT] = {
 	/* Glide/Tranpose - 0 */
 	{"Glide", 1, C0, R0, W1, L1, 0, 1, 0,
@@ -261,6 +423,89 @@ static brightonLocations locations[DEVICE_COUNT] = {
 /*
  */
 
+/*
+ * This is a set of globals for the main window rendering. Again taken from
+ * include/brighton.h
+ */
+brightonApp axxePhatApp = {
+	"axxe",
+	0, /* no blueprint on wood background. */
+	"bitmaps/textures/metal4.xpm",
+	0, /* BRIGHTON_STRETCH, //flags */
+	axxeInit,
+	axxeConfigure, /* 3 callbacks, unused? */
+	midiCallback,
+	destroySynth,
+	{1, 100, 2, 2, 5, 520, 0, 0},
+	600, 350, 0, 0,
+	4, /* Panels */
+	{
+		{
+			"Axxe",
+			"bitmaps/blueprints/axxephat.xpm",
+			"bitmaps/textures/metal6.xpm",
+			BRIGHTON_STRETCH, /* flags */
+			0,
+			0,
+			axxeCallback,
+			15, 0, 970, 620,
+			DEVICE_COUNT,
+			phatlocations
+		},
+#ifdef RIBBON_KEYBOARD
+		{
+			"RibbonKeyboard",
+			0,
+			"bitmaps/newkeys/ribbonKeys.xpm",
+			BRIGHTON_STRETCH,
+			0,
+			ribbonCallBack,
+			ribbonCallBack,
+			80, 625, 840, 360,
+			1,
+			ribbonkeyboard,
+		},
+#else
+		{
+			"Keyboard",
+			0,
+			"bitmaps/newkeys/fkbg.xpm", /* flags */
+			BRIGHTON_STRETCH|BRIGHTON_KEY_PANEL,
+			0,
+			0,
+			keyCallback,
+			80, 625, 840, 360,
+			KEY_COUNT_2OCTAVE2,
+			keys2octave2
+		},
+#endif
+		{
+			"Axxe",
+			0,
+			"bitmaps/textures/metal4.xpm",
+			BRIGHTON_STRETCH|BRIGHTON_VERTICAL, /* flags */
+			0,
+			0,
+			0,
+			0, 0, 15, 1000,
+			0,
+			0
+		},
+		{
+			"Axxe",
+			0,
+			"bitmaps/textures/metal4.xpm",
+			BRIGHTON_STRETCH|BRIGHTON_VERTICAL, /* flags */
+			0,
+			0,
+			0,
+			985, 0, 15, 1000,
+			0,
+			0
+		}
+	}
+};
+
 /*
  * This is a set of globals for the main window rendering. Again taken from
  * include/brighton.h
