@@ -1,7 +1,7 @@
 
 /*
  *  Diverse Bristol audio routines.
- *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2011
+ *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2012
  *
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -317,7 +317,7 @@ brightonApp junoApp = {
 	destroySynth,
 	{6, 100, 1, 2, 5, 520, 0, 0},
 	820, 250, 0, 0,
-	5, /* one panel only */
+	5, /* panels */
 	{
 		{
 			"Juno",
@@ -334,14 +334,15 @@ brightonApp junoApp = {
 		{
 			"Keyboard",
 			0,
-			"bitmaps/newkeys/kbg.xpm", /* flags */
+			"bitmaps/newkeys/nkbg.xpm", /* flags */
 			0x020|BRIGHTON_STRETCH,
 			0,
 			0,
 			keyCallback,
-			114, 562, 891, 425,
+			114, 562, 889, 425,
 			KEY_COUNT,
-			keys
+			//keys
+			keysprofile2
 		},
 		{
 			"Mods",
