@@ -1,7 +1,7 @@
 
 /*
  *  Diverse Bristol audio routines.
- *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2011
+ *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2012
  *
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -320,48 +320,48 @@ static brightonLocations locations[DEVICE_COUNT] = {
 
 	/* Memory/Midi - 94 */
 	/* Load/Save */
-	{"", 2, C20, R3, S2, S1, 0, 1, 0, "bitmaps/buttons/touchogb.xpm",
+	{"", 2, C20 - 4, R3, S2, S1, 0, 1, 0, "bitmaps/buttons/touchogb.xpm",
 		"bitmaps/buttons/touchgb.xpm", BRIGHTON_CHECKBUTTON|BRIGHTON_NOSHADOW},
-	{"", 2, C22, R3, S2, S1, 0, 1, 0, "bitmaps/buttons/touchogb.xpm",
+	{"", 2, C23 + 3, R3, S2, S1, 0, 1, 0, "bitmaps/buttons/touchogb.xpm",
 		"bitmaps/buttons/touchgb.xpm", BRIGHTON_CHECKBUTTON|BRIGHTON_NOSHADOW},
 	/* 1 - 3 */
-	{"", 2, C20, R1_1, S2, S1, 0, 1, 0, "bitmaps/buttons/touchogb.xpm",
+	{"", 2, C20 - 4, R1_1 - 70, S2, S1, 0, 1, 0, "bitmaps/buttons/touchogb.xpm",
 		"bitmaps/buttons/touchgb.xpm", BRIGHTON_CHECKBUTTON|BRIGHTON_NOSHADOW},
-	{"", 2, C21, R1_1, S2, S1, 0, 1, 0, "bitmaps/buttons/touchogb.xpm",
+	{"", 2, C21 + S2, R1_1 - 70, S2, S1, 0, 1, 0, "bitmaps/buttons/touchogb.xpm",
 		"bitmaps/buttons/touchgb.xpm", BRIGHTON_CHECKBUTTON|BRIGHTON_NOSHADOW},
-	{"", 2, C22, R1_1, S2, S1, 0, 1, 0, "bitmaps/buttons/touchogb.xpm",
+	{"", 2, C23 + 3, R1_1 - 70, S2, S1, 0, 1, 0, "bitmaps/buttons/touchogb.xpm",
 		"bitmaps/buttons/touchgb.xpm", BRIGHTON_CHECKBUTTON|BRIGHTON_NOSHADOW},
 	/* 4 - 6 */
-	{"", 2, C20, R21_0, S2, S1, 0, 1, 0, "bitmaps/buttons/touchogb.xpm",
+	{"", 2, C20 - 4, R21_0 - 46, S2, S1, 0, 1, 0, "bitmaps/buttons/touchogb.xpm",
 		"bitmaps/buttons/touchgb.xpm", BRIGHTON_CHECKBUTTON|BRIGHTON_NOSHADOW},
-	{"", 2, C21, R21_0, S2, S1, 0, 1, 0, "bitmaps/buttons/touchogb.xpm",
+	{"", 2, C21 + S2, R21_0 - 46, S2, S1, 0, 1, 0, "bitmaps/buttons/touchogb.xpm",
 		"bitmaps/buttons/touchgb.xpm", BRIGHTON_CHECKBUTTON|BRIGHTON_NOSHADOW},
-	{"", 2, C22, R21_0, S2, S1, 0, 1, 0, "bitmaps/buttons/touchogb.xpm",
+	{"", 2, C23 + 3, R21_0 - 46, S2, S1, 0, 1, 0, "bitmaps/buttons/touchogb.xpm",
 		"bitmaps/buttons/touchgb.xpm", BRIGHTON_CHECKBUTTON|BRIGHTON_NOSHADOW},
 	/* 7 - 9 */
-	{"", 2, C20, R21_1, S2, S1, 0, 1, 0, "bitmaps/buttons/touchogb.xpm",
+	{"", 2, C20 - 4, R21_1 - 23, S2, S1, 0, 1, 0, "bitmaps/buttons/touchogb.xpm",
 		"bitmaps/buttons/touchgb.xpm", BRIGHTON_CHECKBUTTON|BRIGHTON_NOSHADOW},
-	{"", 2, C21, R21_1, S2, S1, 0, 1, 0, "bitmaps/buttons/touchogb.xpm",
+	{"", 2, C21 + S2, R21_1 - 23, S2, S1, 0, 1, 0, "bitmaps/buttons/touchogb.xpm",
 		"bitmaps/buttons/touchgb.xpm", BRIGHTON_CHECKBUTTON|BRIGHTON_NOSHADOW},
-	{"", 2, C22, R21_1, S2, S1, 0, 1, 0, "bitmaps/buttons/touchogb.xpm",
+	{"", 2, C23 + 3, R21_1 - 23, S2, S1, 0, 1, 0, "bitmaps/buttons/touchogb.xpm",
 		"bitmaps/buttons/touchgb.xpm", BRIGHTON_CHECKBUTTON|BRIGHTON_NOSHADOW},
 	/* 0 */
-	{"", 2, C21, R3, S2, S1, 0, 1, 0, "bitmaps/buttons/touchogb.xpm",
+	{"", 2, C21  + S2, R3, S2, S1, 0, 1, 0, "bitmaps/buttons/touchogb.xpm",
 		"bitmaps/buttons/touchgb.xpm", BRIGHTON_CHECKBUTTON|BRIGHTON_NOSHADOW},
 
 /*	{"", 2, C23, R1_1, S2, S1, 0, 1, 0, "bitmaps/buttons/touchogb.xpm", */
 /*		"bitmaps/buttons/touchgb.xpm", BRIGHTON_CHECKBUTTON|BRIGHTON_NOSHADOW}, */
 /*	{"", 2, C23, R21_0, S2, S1, 0, 1, 0, "bitmaps/buttons/touchogb.xpm", */
 /*		"bitmaps/buttons/touchgb.xpm", BRIGHTON_CHECKBUTTON|BRIGHTON_NOSHADOW}, */
-	{"", 2, C23, R21_1, S2, S1, 0, 1, 0, "bitmaps/buttons/touchogb.xpm",
+	{"", 2, C23 + 3, R0, S2, S1, 0, 1, 0, "bitmaps/buttons/touchogb.xpm",
 		"bitmaps/buttons/touchgb.xpm", BRIGHTON_CHECKBUTTON|BRIGHTON_NOSHADOW},
-	{"", 2, C23, R3, S2, S1, 0, 1, 0, "bitmaps/buttons/touchogb.xpm",
+	{"", 2, C20 - 4, R0, S2, S1, 0, 1, 0, "bitmaps/buttons/touchogb.xpm",
 		"bitmaps/buttons/touchgb.xpm", BRIGHTON_CHECKBUTTON|BRIGHTON_NOSHADOW},
 
-	{"", 2, C20, R0, S2, S1, 0, 1, 0, "bitmaps/buttons/touchogb.xpm",
-		"bitmaps/buttons/touchgb.xpm", BRIGHTON_CHECKBUTTON|BRIGHTON_NOSHADOW},
-	{"", 2, C23, R0, S2, S1, 0, 1, 0, "bitmaps/buttons/touchogb.xpm",
-		"bitmaps/buttons/touchgb.xpm", BRIGHTON_CHECKBUTTON|BRIGHTON_NOSHADOW},
+	{"", 2, 0, 0, S2, S1, 0, 1, 0, "bitmaps/buttons/touchogb.xpm",
+		"bitmaps/buttons/touchgb.xpm", BRIGHTON_CHECKBUTTON|BRIGHTON_WITHDRAWN},
+	{"", 2, 0, 0, S2, S1, 0, 1, 0, "bitmaps/buttons/touchogb.xpm",
+		"bitmaps/buttons/touchgb.xpm", BRIGHTON_CHECKBUTTON|BRIGHTON_WITHDRAWN},
 
 	{"", 4, 790, 1020, 180, 140, 0, 1, 0, "bitmaps/images/memorymoog.xpm",0, 0},
 
@@ -404,14 +404,14 @@ brightonApp memMoogApp = {
 		{
 			"Keyboard",
 			0,
-			"bitmaps/newkeys/kbg.xpm", /* flags */
+			"bitmaps/newkeys/nkbg.xpm", /* flags */
 			0x020|BRIGHTON_STRETCH,
 			0,
 			0,
 			keyCallback,
 			100, 650, 913, 340,
-			KEY_COUNT,
-			keys
+			KEY_COUNT_5OCTAVE,
+			keysprofile2
 		},
 		{
 			"Mods",
@@ -1274,7 +1274,7 @@ memMoogInit(brightonWindow *win)
 
 	/* Depth controls */
 	dispatch[89].controller = 126;
-	dispatch[89].operator = 126;
+	dispatch[89].operator = 47;
 	dispatch[90].controller = 126;
 	dispatch[90].operator = 3;
 
@@ -1324,6 +1324,7 @@ memMoogInit(brightonWindow *win)
 	dispatch[OSC_3_RADIO].other1 = -1;
 
 	/* Put in diverse defaults settings */
+	bristolMidiSendMsg(global.controlfd, synth->sid, 7, 0, 16383);
 	/* Tune osc-1 */
 	bristolMidiSendMsg(global.controlfd, synth->sid, 0, 2, 8192);
 	/* Gain on filter env - changed to fixed MOD on filter, variable Env. Then */
