@@ -1,7 +1,7 @@
 
 /*
  *  Diverse Bristol audio routines.
- *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2011
+ *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2012
  *
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -148,14 +148,14 @@ static brightonLocations locations[DEVICE_COUNT] = {
 		0, 0},
 	{"Release", 0, C9, R5, S1, S1, 0, 1, 0, "bitmaps/knobs/knob4.xpm", 
 		0, 0}, /*25 */
-/* MAIN OUT */
+/* MAIN OUT 25 */
 	{"MasterVolume", 0, C10, R1, S3, S3, 0, 1, 0, "bitmaps/knobs/knob4.xpm", 
 		0, 0},
 	{"On/Off", 2, C10 + 7, R1 - 92, B1, B1, 0, 1, 0,
 		"bitmaps/buttons/rockerblue.xpm", 0, 0},
 	{"A-440", 2, C10 + 7, R2 + 75, B1, B1, 0, 1, 0, 
 		"bitmaps/buttons/rockerblue.xpm", 0, 0}, /*28 */
-/* MIX BUTTONS */
+/* MIX BUTTONS - 28 */
 	{"Mix Osc1", 2, C5, R1 + 45, B1, B1, 0, 1, 0, 
 		"bitmaps/buttons/rockerblue.xpm", 0, 0},
 	{"Mix Ext", 2, C5, R2 + 45, B1, B1, 0, 1, 0, 
@@ -166,10 +166,10 @@ static brightonLocations locations[DEVICE_COUNT] = {
 		"bitmaps/buttons/rockerblue.xpm", 0, 0},
 	{"Mix Osc3", 2, C5, R5 + 45, B1, B1, 0, 1, 0, 
 		"bitmaps/buttons/rockerblue.xpm", 0, 0}, /*33 */
-/* NOISE BUTTON */
+/* NOISE BUTTON - 33 */
 	{"White/Pink", 2, C11 - 6, C6, B2, B3, 0, 1, 0, 
 		"bitmaps/buttons/rockerblue.xpm", 0, BRIGHTON_VERTICAL}, /*34 */
-/* CONTROL BUTTONS */
+/* CONTROL BUTTONS - 34 */
 	{"Osc Mod 1", 2, C12 - 22, R2 - 13, B1, B1, 0, 1, 0, 0, 0, 0},
 	{"Osc Mod 2", 2, C12 - 22, R2 + 97, B1, B1, 0, 1, 0, 0, 0, 0},
 	{"Osc 3 LFO", 2, C12 - 9, R5 + 15, B2, B3, 0, 1, 0, 0, 0, BRIGHTON_VERTICAL},
@@ -177,7 +177,7 @@ static brightonLocations locations[DEVICE_COUNT] = {
 		"bitmaps/buttons/rockerwhite.xpm", 0, 0},
 	{"Multitrig", 2, 78, 825, B1, B1, 0, 1, 0,
 		"bitmaps/buttons/rockerwhite.xpm", 0, 0}, /*39 */
-/* FILTER BUTTONS */
+/* FILTER BUTTONS - 39 */
 	{"Filter Mod1", 2, C11 - 5, R1 + 30, B1, B1, 0, 1, 0, 0, 0, 0},
 	{"Filter Velocity", 2, C11 - 5, R1 + 170, B1, B1, 0, 1, 0, 0, 0, 0},
 	{"Filter KBD", 2, C11 - 5, R3, B1, B1, 0, 1, 0, 0, 0}, /*42 */
@@ -256,8 +256,8 @@ brightonApp miniApp = {
 		{
 			"Keyboard",
 			0,
-			"bitmaps/newkeys/ekbg.xpm", /* flags */
-			0x020|BRIGHTON_STRETCH,
+			"bitmaps/newkeys/ekbg.xpm",
+			0x020|BRIGHTON_STRETCH|BRIGHTON_KEY_PANEL,
 			0,
 			0,
 			keyCallback,
@@ -398,7 +398,10 @@ miniDualFilterDecay(guiSynth *synth, int fd, int chan, int c, int o, int v)
 {
 	bristolMidiSendMsg(fd, chan, c, 1, v);
 
-	bristolMidiSendMsg(fd, chan, c, 3, v);
+	if (synth->mem.param[FIRST_DEV + 37])
+		bristolMidiSendMsg(fd, chan, c, 3, v);
+	else
+		bristolMidiSendMsg(fd, chan, c, 3, 1024);
 }
 
 static void
@@ -411,7 +414,7 @@ miniDualDecay(guiSynth *synth, int fd, int chan, int c, int o, int v)
 		bristolMidiSendMsg(fd, chan, 5, 3,
 			(int) (synth->mem.param[FIRST_DEV + 23] * C_RANGE_MIN_1));
 	else
-		bristolMidiSendMsg(fd, chan, 5, 3, 20);
+		bristolMidiSendMsg(fd, chan, 5, 3, 1024);
 }
 
 static void
