@@ -1,7 +1,7 @@
 
 /*
  *  Diverse Bristol audio routines.
- *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2011
+ *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2012
  *
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -261,7 +261,8 @@ static brightonLocations locations2[DEVICE_COUNT] = {
 	/* Glide/Tranpose - 0 */
 	{"", 1, C0, R0, W1, L1, 0, 1, 0,
 		"bitmaps/knobs/sliderblack3.xpm", 0, 0},
-	{"", 2, C1, R2, 15, L1/2 - 10, 0, 2, 0, 0, 0,
+//	{"", 2, C1, R2, 15, L1/2 - 10, 0, 2, 0, 0, 0,
+	{"Transpose", 2, C1, R2 + 20, 15, L1/2 - 40, 0, 2, 0, 0, 0,
 		BRIGHTON_THREEWAY|BRIGHTON_NOSHADOW},
 
 	/* VCO - 2 */
