@@ -1,7 +1,7 @@
 
 /*
  *  Diverse Bristol audio routines.
- *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2011
+ *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2012
  *
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -1057,12 +1057,12 @@ pro1Init(brightonWindow *win)
 	dispatch[31].operator = 101;
 	dispatch[31].routine = (synthRoutine) pro1Arpeggiate;
 	/* Modes, need to read up on function */
-	dispatch[32].controller = 5; /* Rezero envelope on trigger */
-	dispatch[32].operator = 6;
-	dispatch[33].controller = 126;
+	dispatch[32].controller = 126; /* multitrig envelope note */
+	dispatch[32].operator = 27;
+	dispatch[33].controller = 126; /* Track LFO as trigger */
 	dispatch[33].operator = 9;
-	dispatch[34].controller = 126;
-	dispatch[34].operator = 101;
+	dispatch[34].controller = 126; /* Force gate open */
+	dispatch[34].operator = 28;
 	dispatch[34].routine = (synthRoutine) pro1Hold; /* Drone */
 
 	/* Mixer */
