@@ -1,7 +1,7 @@
 
 /*
  *  Diverse Bristol audio routines.
- *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2011
+ *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2012
  *
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -298,6 +298,7 @@ doAudioOps(audioMain *audiomain, float *outbuf, float *startbuf)
 
 				continue;
 			}
+			v->offset = 0;
 			v = v->next;
 		}
 
@@ -431,7 +432,7 @@ doAudioOps(audioMain *audiomain, float *outbuf, float *startbuf)
 				 * This looks a bit brutal however the assignement code should
 				 * avoid this situation.
 				 */
-				if (voice->baudio->midiflags & BRISTOL_MIDI_DEBUG1)
+				if (voice->baudio->midiflags & BRISTOL_MIDI_DEBUG2)
 					printf("overvoice keydone\n");
 
 				voice->flags |= BRISTOL_KEYOFF;
