@@ -1,7 +1,7 @@
 
 /*
  *  Diverse Bristol audio routines.
- *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2011
+ *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2012
  *
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -1215,6 +1215,11 @@ doNoteChanges(bristolVoice *voice)
 			voice->dFreq = voice->baudio->ctab[voice->key.key].step;
 			voice->dfreq = voice->baudio->ctab[voice->key.key].freq;
 		}
+
+		if (voice->detune != 0.0) {
+			voice->dFreq *= voice->detune;
+			voice->dfreq *= voice->detune;
+		}
 	}
 }
 
