@@ -1,7 +1,7 @@
 
 /*
  *  Diverse Bristol audio routines.
- *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2011
+ *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2012
  *
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -127,15 +127,6 @@ arp2600Controller(Baudio *baudio, u_char operator, u_char controller, float valu
 	printf("bristolArp2600Control(%i, %i, %f)\n", operator, controller, value);
 #endif
 
-	/*
-	 * 98 will be the dimension D
-	 */
-	if (operator == 98)
-	{
-		baudio->effect[0]->param->param[controller].float_val = value;
-		return(0);
-	}
-
 	/*
 	 * 99 will be the reverb
 	 */
@@ -363,12 +354,15 @@ operateOneArp2600(audioMain *audiomain, Baudio *baudio,
 bristolVoice *voice, register float *startbuf)
 {
 	arp2600mods *mods = (arp2600mods *) baudio->mixlocals;
-	int sc = audiomain->samplecount, kflags = 0;
+	int sc = audiomain->samplecount, kflags = 0, vindex = 0;
 	int ss = audiomain->segmentsize, i;
-	float *b = abufs.outputs[voice->index][ARP_O_PREAMP], g;
-	float *s = abufs.outputs[0][ARP_O_PREAMP];
+	float *s = abufs.outputs[0][ARP_O_PREAMP], *b, g;
 
-/*printf("operateOneArp2600(%i, %x, %x)\n", voice->index, audiomain, baudio); */
+/*printf("operateOneArp2600(%i, %x, %x)\n", vindex, audiomain, baudio); */
+
+	vindex = voice->index;
+
+	b = abufs.outputs[vindex][ARP_O_PREAMP];
 
 	/*
 	 * As of 0.50.4 we should be supporting 4 IO for CV or audio from Jack,
@@ -383,22 +377,22 @@ bristolVoice *voice, register float *startbuf)
 
 			bufmerge(
 				audiomain->io_i[i], 12.0f, //4.0 * audiomain->m_io_igc,
-				abufs.outputs[voice->index][ARP_O_IN_1 + i], 0.0,
+				abufs.outputs[vindex][ARP_O_IN_1 + i], 0.0,
 				sc);
 		}
 	}
 
-	bristolbzero(abufs.inputs[voice->index][ARP_I_OUT_1], sc);
-	bristolbzero(abufs.inputs[voice->index][ARP_I_OUT_2], sc);
-	bristolbzero(abufs.inputs[voice->index][ARP_I_OUT_3], sc);
-	bristolbzero(abufs.inputs[voice->index][ARP_I_OUT_4], sc);
+	bristolbzero(abufs.inputs[vindex][ARP_I_OUT_1], sc);
+	bristolbzero(abufs.inputs[vindex][ARP_I_OUT_2], sc);
+	bristolbzero(abufs.inputs[vindex][ARP_I_OUT_3], sc);
+	bristolbzero(abufs.inputs[vindex][ARP_I_OUT_4], sc);
 
 /* Preamp patching and envelope follower. */
 	/*
 	 * Since the input buffer is singular and we may have multiple voice, then
 	 * to get the correct routing we need to copy this to each voice buffers.
 	 */
-	if (voice->index != 0)
+	if (vindex != 0)
 	{
 		for (i = 0; i < sc; i+=8)
 		{
@@ -415,47 +409,47 @@ bristolVoice *voice, register float *startbuf)
 
 	/* Envelope follower. */
 	audiomain->palette[(*baudio->sound[11]).index]->specs->io[0].buf =
-		abufs.inputs[voice->index][ARP_I_ENVFOLLOW];
+		abufs.inputs[vindex][ARP_I_ENVFOLLOW];
 	audiomain->palette[(*baudio->sound[11]).index]->specs->io[1].buf =
-		abufs.outputs[voice->index][ARP_O_ENVFOLLOW];
+		abufs.outputs[vindex][ARP_O_ENVFOLLOW];
 	(*baudio->sound[11]).operate(
 		(audiomain->palette)[23],
 		voice,
 		(*baudio->sound[11]).param,
-		voice->locals[voice->index][11]);
+		voice->locals[vindex][11]);
 /* Preamp done */
 
 /* NOISE */
 	/*
 	 * This had to be moved to a multi operator to support the correct routing.
 	 */
-	bristolbzero(abufs.outputs[voice->index][ARP_O_NOISE], ss);
+	bristolbzero(abufs.outputs[vindex][ARP_O_NOISE], ss);
 	audiomain->palette[(*baudio->sound[6]).index]->specs->io[0].buf =
-		abufs.outputs[voice->index][ARP_O_NOISE];
+		abufs.outputs[vindex][ARP_O_NOISE];
 	(*baudio->sound[6]).operate(
 		(audiomain->palette)[4],
 		voice,
 		(*baudio->sound[6]).param,
-		voice->locals[voice->index][6]);
+		voice->locals[vindex][6]);
 /* NOISE DONE */
 
 /* LFO */
 	audiomain->palette[(*baudio->sound[9]).index]->specs->io[0].buf
-		= abufs.inputs[voice->index][ARP_I_SH_IN];
+		= abufs.inputs[vindex][ARP_I_SH_IN];
 	audiomain->palette[(*baudio->sound[9]).index]->specs->io[1].buf
-		= abufs.outputs[voice->index][ARP_O_CLOCK];
+		= abufs.outputs[vindex][ARP_O_CLOCK];
 	audiomain->palette[(*baudio->sound[9]).index]->specs->io[3].buf
-		= abufs.outputs[voice->index][ARP_O_SH];
+		= abufs.outputs[vindex][ARP_O_SH];
 
 	(*baudio->sound[9]).operate(
 		(audiomain->palette)[16],
 		voice,
 		(*baudio->sound[9]).param,
-		voice->locals[voice->index][9]);
+		voice->locals[vindex][9]);
 	/*
 	 * Apply a gain to the LFO for mods.
 	 */
-	bufmerge(abufs.outputs[voice->index][ARP_O_KBD_CV], 0.0, abufs.outputs[voice->index][ARP_O_CLOCK],
+	bufmerge(abufs.outputs[vindex][ARP_O_KBD_CV], 0.0, abufs.outputs[vindex][ARP_O_CLOCK],
 		4.0 * mods->lfogain, sc);
 /* */
 
@@ -480,20 +474,20 @@ bristolVoice *voice, register float *startbuf)
 		/*
 		 * We have a buffer, see if we need to detect edge.
 		 */
-		if ((*abufs.inputs[voice->index][ARP_I_AR_GATE] > 0) &&
+		if ((*abufs.inputs[vindex][ARP_I_AR_GATE] > 0) &&
 			((voice->flags & (BRISTOL_KEYOFF|BRISTOL_KEYOFFING)) == 0))
 				voice->flags |= BRISTOL_KEYREON;
-		if (*abufs.inputs[voice->index][ARP_I_AR_GATE] < 0)
+		if (*abufs.inputs[vindex][ARP_I_AR_GATE] < 0)
 				voice->flags |= BRISTOL_KEYOFF;
 	}
 
 	audiomain->palette[(*baudio->sound[7]).index]->specs->io[0].buf
-		= abufs.outputs[voice->index][ARP_O_AR];
+		= abufs.outputs[vindex][ARP_O_AR];
 	(*baudio->sound[7]).operate(
 		(audiomain->palette)[1],
 		voice,
 		(*baudio->sound[7]).param,
-		voice->locals[voice->index][7]);
+		voice->locals[vindex][7]);
 
 	voice->flags = kflags;
 
@@ -501,12 +495,12 @@ bristolVoice *voice, register float *startbuf)
 	 * Run the ADSR.
 	 */
 	audiomain->palette[(*baudio->sound[4]).index]->specs->io[0].buf =
-		abufs.outputs[voice->index][ARP_O_ADSR];
+		abufs.outputs[vindex][ARP_O_ADSR];
 	(*baudio->sound[4]).operate(
 		(audiomain->palette)[1],
 		voice,
 		(*baudio->sound[4]).param,
-		voice->locals[voice->index][4]);
+		voice->locals[vindex][4]);
 
 /*
 	if (mods->adsrAuto)
@@ -525,14 +519,14 @@ bristolVoice *voice, register float *startbuf)
 	audiomain->palette[(*baudio->sound[0]).index]->specs->io[0].buf = fmbuf;
 	audiomain->palette[(*baudio->sound[0]).index]->specs->io[1].buf = zerobuf;
 	audiomain->palette[(*baudio->sound[0]).index]->specs->io[2].buf =
-		abufs.outputs[voice->index][ARP_O_VCO1_SAW];
+		abufs.outputs[vindex][ARP_O_VCO1_SAW];
 	audiomain->palette[(*baudio->sound[0]).index]->specs->io[3].buf = NULL;
 	audiomain->palette[(*baudio->sound[0]).index]->specs->io[4].buf =
-		abufs.outputs[voice->index][ARP_O_VCO1_SQR];
+		abufs.outputs[vindex][ARP_O_VCO1_SQR];
 	audiomain->palette[(*baudio->sound[0]).index]->specs->io[5].buf = NULL;
 	audiomain->palette[(*baudio->sound[0]).index]->specs->io[6].buf = NULL;
-/*printf("%i: osc1 to %x\n", voice->index, */
-/*abufs.outputs[voice->index][ARP_O_VCO1_SQR]); */
+/*printf("%i: osc1 to %x\n", vindex, */
+/*abufs.outputs[vindex][ARP_O_VCO1_SQR]); */
 
 	/*
 	 * We need to make this connection for CV KBD open again. If nothing is
@@ -545,10 +539,10 @@ bristolVoice *voice, register float *startbuf)
 	 * others.
 	 */
 	fillFreqTable(baudio, voice,
-		abufs.outputs[voice->index][ARP_O_KBD_CV], sc, 1);
+		abufs.outputs[vindex][ARP_O_KBD_CV], sc, 1);
 
 	if (mods->flags & ARP_OSC1_TRACKING)
-		bufmerge(abufs.inputs[voice->index][ARP_I_VCO1_KBD], 1.0,
+		bufmerge(abufs.inputs[vindex][ARP_I_VCO1_KBD], 1.0,
 			fmbuf, 0.0, sc);
 	else {
 		register int i;
@@ -560,8 +554,8 @@ bristolVoice *voice, register float *startbuf)
 			mult = 0.10;
 		}
 
-		if (abufs.inputs[voice->index][ARP_I_VCO1_KBD] == 
-			abufs.outputs[voice->index][ARP_O_KBD_CV])
+		if (abufs.inputs[vindex][ARP_I_VCO1_KBD] == 
+			abufs.outputs[vindex][ARP_O_KBD_CV])
 			mult *= baudio->contcontroller[1];
 
 		mult += value;
@@ -595,44 +589,44 @@ bristolVoice *voice, register float *startbuf)
 	 * There are 3 FM (KBD CV separate) and 1 PM.
 	 */
 	if (abufs.gains[ARP_I_VCO1_SH] != 0.0f)
-		bufmerge(abufs.inputs[voice->index][ARP_I_VCO1_SH],
+		bufmerge(abufs.inputs[vindex][ARP_I_VCO1_SH],
 			abufs.gains[ARP_I_VCO1_SH], fmbuf, 1.0, sc);
 	if (abufs.gains[ARP_I_VCO1_ADSR] != 0.0f)
-		bufmerge(abufs.inputs[voice->index][ARP_I_VCO1_ADSR],
+		bufmerge(abufs.inputs[vindex][ARP_I_VCO1_ADSR],
 			abufs.gains[ARP_I_VCO1_ADSR], fmbuf, 1.0, sc);
 	if (abufs.gains[ARP_I_VCO1_VCO2] != 0.0f)
-		bufmerge(abufs.inputs[voice->index][ARP_O_VCO2_SIN],
+		bufmerge(abufs.inputs[vindex][ARP_O_VCO2_SIN],
 			abufs.gains[ARP_I_VCO1_VCO2], fmbuf, 1.0, sc);
 
-	bristolbzero(abufs.outputs[voice->index][ARP_O_VCO1_SAW], ss);
-	bristolbzero(abufs.outputs[voice->index][ARP_O_VCO1_SQR], ss);
+	bristolbzero(abufs.outputs[vindex][ARP_O_VCO1_SAW], ss);
+	bristolbzero(abufs.outputs[vindex][ARP_O_VCO1_SQR], ss);
 
 	(*baudio->sound[0]).operate(
 		(audiomain->palette)[19],
 		voice,
 		(*baudio->sound[0]).param,
-		voice->locals[voice->index][0]);
+		voice->locals[vindex][0]);
 
 /* done-1 */
 
 	audiomain->palette[(*baudio->sound[1]).index]->specs->io[0].buf = fmbuf;
 	audiomain->palette[(*baudio->sound[1]).index]->specs->io[1].buf = scratch;
 	audiomain->palette[(*baudio->sound[1]).index]->specs->io[2].buf =
-		abufs.outputs[voice->index][ARP_O_VCO2_SAW];
+		abufs.outputs[vindex][ARP_O_VCO2_SAW];
 	audiomain->palette[(*baudio->sound[1]).index]->specs->io[3].buf =
-		abufs.outputs[voice->index][ARP_O_VCO1_SQR]; /* sync source */
+		abufs.outputs[vindex][ARP_O_VCO1_SQR]; /* sync source */
 	audiomain->palette[(*baudio->sound[1]).index]->specs->io[4].buf =
-		abufs.outputs[voice->index][ARP_O_VCO2_SQR];
+		abufs.outputs[vindex][ARP_O_VCO2_SQR];
 	audiomain->palette[(*baudio->sound[1]).index]->specs->io[5].buf =
-		abufs.outputs[voice->index][ARP_O_VCO2_SIN];
+		abufs.outputs[vindex][ARP_O_VCO2_SIN];
 	audiomain->palette[(*baudio->sound[1]).index]->specs->io[6].buf =
-		abufs.outputs[voice->index][ARP_O_VCO2_TRI];
+		abufs.outputs[vindex][ARP_O_VCO2_TRI];
 
 	/*
 	 * Fill our fmbuf scratch table again.
 	 */
 	if (mods->flags & ARP_OSC2_TRACKING)
-		bufmerge(abufs.inputs[voice->index][ARP_I_VCO2_KBD], 1.0,
+		bufmerge(abufs.inputs[vindex][ARP_I_VCO2_KBD], 1.0,
 			fmbuf, 0.0, sc);
 	else {
 		register int i;
@@ -644,8 +638,8 @@ bristolVoice *voice, register float *startbuf)
 			mult = 0.10;
 		}
 
-		if (abufs.inputs[voice->index][ARP_I_VCO2_KBD] == 
-			abufs.outputs[voice->index][ARP_O_KBD_CV])
+		if (abufs.inputs[vindex][ARP_I_VCO2_KBD] == 
+			abufs.outputs[vindex][ARP_O_KBD_CV])
 			mult *= baudio->contcontroller[1];
 
 		mult += value;
@@ -673,50 +667,50 @@ bristolVoice *voice, register float *startbuf)
 	}
 
 	if (abufs.gains[ARP_I_VCO2_SH] != 0.0f)
-		bufmerge(abufs.inputs[voice->index][ARP_I_VCO2_SH],
+		bufmerge(abufs.inputs[vindex][ARP_I_VCO2_SH],
 			abufs.gains[ARP_I_VCO2_SH], fmbuf, 1.0, sc);
 
 	if (abufs.gains[ARP_I_VCO2_ADSR] != 0.0f)
-		bufmerge(abufs.inputs[voice->index][ARP_I_VCO2_ADSR],
+		bufmerge(abufs.inputs[vindex][ARP_I_VCO2_ADSR],
 			abufs.gains[ARP_I_VCO2_ADSR], fmbuf, 1.0, sc);
 
 	if (abufs.gains[ARP_I_VCO2_VCO1] != 0.0f)
-		bufmerge(abufs.inputs[voice->index][ARP_I_VCO2_VCO1],
+		bufmerge(abufs.inputs[vindex][ARP_I_VCO2_VCO1],
 			abufs.gains[ARP_I_VCO2_VCO1], fmbuf, 1.0, sc);
 
-	bufmerge(abufs.inputs[voice->index][ARP_I_VCO2_NSE],
+	bufmerge(abufs.inputs[vindex][ARP_I_VCO2_NSE],
 		abufs.gains[ARP_I_VCO2_NSE] * 48, scratch, 0.0, sc);
 
-	bristolbzero(abufs.outputs[voice->index][ARP_O_VCO2_SAW], ss);
-	bristolbzero(abufs.outputs[voice->index][ARP_O_VCO2_SQR], ss);
-	bristolbzero(abufs.outputs[voice->index][ARP_O_VCO2_SIN], ss);
-	bristolbzero(abufs.outputs[voice->index][ARP_O_VCO2_TRI], ss);
+	bristolbzero(abufs.outputs[vindex][ARP_O_VCO2_SAW], ss);
+	bristolbzero(abufs.outputs[vindex][ARP_O_VCO2_SQR], ss);
+	bristolbzero(abufs.outputs[vindex][ARP_O_VCO2_SIN], ss);
+	bristolbzero(abufs.outputs[vindex][ARP_O_VCO2_TRI], ss);
 
 	(*baudio->sound[1]).operate(
 		(audiomain->palette)[19],
 		voice,
 		(*baudio->sound[1]).param,
-		voice->locals[voice->index][1]);
+		voice->locals[vindex][1]);
 
 /* done-2 */
 
 	audiomain->palette[(*baudio->sound[1]).index]->specs->io[0].buf = fmbuf;
 	audiomain->palette[(*baudio->sound[1]).index]->specs->io[1].buf = scratch;
 	audiomain->palette[(*baudio->sound[1]).index]->specs->io[2].buf =
-		abufs.outputs[voice->index][ARP_O_VCO3_SAW];
+		abufs.outputs[vindex][ARP_O_VCO3_SAW];
 	audiomain->palette[(*baudio->sound[1]).index]->specs->io[3].buf = zerobuf;
 	audiomain->palette[(*baudio->sound[1]).index]->specs->io[4].buf =
-		abufs.outputs[voice->index][ARP_O_VCO3_SQR];
+		abufs.outputs[vindex][ARP_O_VCO3_SQR];
 	audiomain->palette[(*baudio->sound[1]).index]->specs->io[5].buf =
-		abufs.outputs[voice->index][ARP_O_VCO3_SIN];
+		abufs.outputs[vindex][ARP_O_VCO3_SIN];
 	audiomain->palette[(*baudio->sound[1]).index]->specs->io[6].buf =
-		abufs.outputs[voice->index][ARP_O_VCO3_TRI];
+		abufs.outputs[vindex][ARP_O_VCO3_TRI];
 
 	/*
 	 * Fill our fmbuf scratch table again.
 	 */
 	if (mods->flags & ARP_OSC3_TRACKING)
-		bufmerge(abufs.inputs[voice->index][ARP_I_VCO3_KBD], 1.0,
+		bufmerge(abufs.inputs[vindex][ARP_I_VCO3_KBD], 1.0,
 			fmbuf, 0.0, sc);
 	else {
 		register int i;
@@ -728,8 +722,8 @@ bristolVoice *voice, register float *startbuf)
 			mult = 0.10;
 		}
 
-		if (abufs.inputs[voice->index][ARP_I_VCO3_KBD] == 
-			abufs.outputs[voice->index][ARP_O_KBD_CV])
+		if (abufs.inputs[vindex][ARP_I_VCO3_KBD] == 
+			abufs.outputs[vindex][ARP_O_KBD_CV])
 			mult *= baudio->contcontroller[1];
 
 		mult += value;
@@ -757,42 +751,42 @@ bristolVoice *voice, register float *startbuf)
 	}
 
 	if (abufs.gains[ARP_I_VCO3_NSE] != 0.0f)
-		bufmerge(abufs.inputs[voice->index][ARP_I_VCO3_NSE],
+		bufmerge(abufs.inputs[vindex][ARP_I_VCO3_NSE],
 			abufs.gains[ARP_I_VCO3_NSE], fmbuf, 1.0, sc);
 	if (abufs.gains[ARP_I_VCO3_ADSR] != 0.0f)
-		bufmerge(abufs.inputs[voice->index][ARP_I_VCO3_ADSR],
+		bufmerge(abufs.inputs[vindex][ARP_I_VCO3_ADSR],
 			abufs.gains[ARP_I_VCO3_ADSR], fmbuf, 1.0, sc);
 	if (abufs.gains[ARP_I_VCO3_SIN] != 0.0f)
-		bufmerge(abufs.inputs[voice->index][ARP_I_VCO3_SIN],
+		bufmerge(abufs.inputs[vindex][ARP_I_VCO3_SIN],
 			abufs.gains[ARP_I_VCO3_SIN], fmbuf, 1.0, sc);
 
-	bufmerge(abufs.inputs[voice->index][ARP_I_VCO3_TRI],
+	bufmerge(abufs.inputs[vindex][ARP_I_VCO3_TRI],
 		abufs.gains[ARP_I_VCO3_TRI] * 48, scratch, 0.0, sc);
 
-	bristolbzero(abufs.outputs[voice->index][ARP_O_VCO3_SAW], ss);
-	bristolbzero(abufs.outputs[voice->index][ARP_O_VCO3_SQR], ss);
-	bristolbzero(abufs.outputs[voice->index][ARP_O_VCO3_SIN], ss);
-	bristolbzero(abufs.outputs[voice->index][ARP_O_VCO3_TRI], ss);
+	bristolbzero(abufs.outputs[vindex][ARP_O_VCO3_SAW], ss);
+	bristolbzero(abufs.outputs[vindex][ARP_O_VCO3_SQR], ss);
+	bristolbzero(abufs.outputs[vindex][ARP_O_VCO3_SIN], ss);
+	bristolbzero(abufs.outputs[vindex][ARP_O_VCO3_TRI], ss);
 
 	(*baudio->sound[2]).operate(
 		(audiomain->palette)[19],
 		voice,
 		(*baudio->sound[2]).param,
-		voice->locals[voice->index][2]);
+		voice->locals[vindex][2]);
 /* OSC done */
 
 /* Ring mod */
 	audiomain->palette[(*baudio->sound[8]).index]->specs->io[0].buf
-		= abufs.inputs[voice->index][ARP_I_RM1];
+		= abufs.inputs[vindex][ARP_I_RM1];
 	audiomain->palette[(*baudio->sound[8]).index]->specs->io[1].buf
-		= abufs.inputs[voice->index][ARP_I_RM2];
+		= abufs.inputs[vindex][ARP_I_RM2];
 	audiomain->palette[(*baudio->sound[8]).index]->specs->io[2].buf
-		= abufs.outputs[voice->index][ARP_O_RINGMOD];
+		= abufs.outputs[vindex][ARP_O_RINGMOD];
 	(*baudio->sound[8]).operate(
 		(audiomain->palette)[20],
 		voice,
 		(*baudio->sound[8]).param,
-		voice->locals[voice->index][8]);
+		voice->locals[vindex][8]);
 /* */
 
 /* Voltage processors */
@@ -803,35 +797,35 @@ bristolVoice *voice, register float *startbuf)
 	 *
 	 * These are controllers 44 to 47.
 	 */
-	bufmerge(abufs.inputs[voice->index][ARP_I_MIX_1_1],
+	bufmerge(abufs.inputs[vindex][ARP_I_MIX_1_1],
 		abufs.gains[ARP_I_MIX_1_1] * 2.0f,
-		abufs.outputs[voice->index][ARP_O_MIX_1], 0.0, sc);
-	bufmerge(abufs.inputs[voice->index][ARP_I_MIX_1_2],
+		abufs.outputs[vindex][ARP_O_MIX_1], 0.0, sc);
+	bufmerge(abufs.inputs[vindex][ARP_I_MIX_1_2],
 		abufs.gains[ARP_I_MIX_1_2] * 2.0f,
-		abufs.outputs[voice->index][ARP_O_MIX_1], 1.0, sc);
-	bufmerge(abufs.inputs[voice->index][ARP_I_MIX_1_3], 1.0,
-		abufs.outputs[voice->index][ARP_O_MIX_1], 1.0, sc);
-	bufmerge(abufs.inputs[voice->index][ARP_I_MIX_1_4], 1.0,
-		abufs.outputs[voice->index][ARP_O_MIX_1], 1.0, sc);
+		abufs.outputs[vindex][ARP_O_MIX_1], 1.0, sc);
+	bufmerge(abufs.inputs[vindex][ARP_I_MIX_1_3], 1.0,
+		abufs.outputs[vindex][ARP_O_MIX_1], 1.0, sc);
+	bufmerge(abufs.inputs[vindex][ARP_I_MIX_1_4], 1.0,
+		abufs.outputs[vindex][ARP_O_MIX_1], 1.0, sc);
 
 	/* Invert the signal */
-	invert(abufs.outputs[voice->index][ARP_O_MIX_1],
-		abufs.outputs[voice->index][ARP_O_MIX_1], sc);
+	invert(abufs.outputs[vindex][ARP_O_MIX_1],
+		abufs.outputs[vindex][ARP_O_MIX_1], sc);
 
-	bufmerge(abufs.inputs[voice->index][ARP_I_MIX_2_1],
+	bufmerge(abufs.inputs[vindex][ARP_I_MIX_2_1],
 		abufs.gains[ARP_I_MIX_2_1] * 2.0f,
-		abufs.outputs[voice->index][ARP_O_MIX_2], 0.0, sc);
-	bufmerge(abufs.inputs[voice->index][ARP_I_MIX_2_2], 1.0,
-		abufs.outputs[voice->index][ARP_O_MIX_2], 1.0, sc);
+		abufs.outputs[vindex][ARP_O_MIX_2], 0.0, sc);
+	bufmerge(abufs.inputs[vindex][ARP_I_MIX_2_2], 1.0,
+		abufs.outputs[vindex][ARP_O_MIX_2], 1.0, sc);
 	/* Invert the signal */
-	invert(abufs.outputs[voice->index][ARP_O_MIX_2],
-		abufs.outputs[voice->index][ARP_O_MIX_2], sc);
+	invert(abufs.outputs[vindex][ARP_O_MIX_2],
+		abufs.outputs[vindex][ARP_O_MIX_2], sc);
 
 	/*
 	 * Build the second output
 	 */
-	bufmerge(abufs.outputs[voice->index][ARP_O_MIX_2], 1.0,
-		abufs.outputs[voice->index][ARP_O_MIX_2_2], 0.0, sc);
+	bufmerge(abufs.outputs[vindex][ARP_O_MIX_2], 1.0,
+		abufs.outputs[vindex][ARP_O_MIX_2_2], 0.0, sc);
 
 	/*
 	 * The lag processor. Hm, this is actually very similar to a rooney filter
@@ -839,44 +833,44 @@ bristolVoice *voice, register float *startbuf)
 	 * not a modified one with emphasis.
 	 */
 	audiomain->palette[(*baudio->sound[12]).index]->specs->io[0].buf
-		= abufs.inputs[voice->index][ARP_I_LAG];
+		= abufs.inputs[vindex][ARP_I_LAG];
 	audiomain->palette[(*baudio->sound[12]).index]->specs->io[2].buf
-		= abufs.outputs[voice->index][ARP_O_LAG];
+		= abufs.outputs[vindex][ARP_O_LAG];
 	(*baudio->sound[12]).operate(
 		(audiomain->palette)[3],
 		voice,
 		(*baudio->sound[12]).param,
-		voice->locals[voice->index][12]);
+		voice->locals[vindex][12]);
 /* */
 
 /* VP */
 
 /* Electroswitch */
 	audiomain->palette[(*baudio->sound[10]).index]->specs->io[0].buf
-		= abufs.inputs[voice->index][ARP_I_SWITCH_1];
+		= abufs.inputs[vindex][ARP_I_SWITCH_1];
 	audiomain->palette[(*baudio->sound[10]).index]->specs->io[1].buf
-		= abufs.inputs[voice->index][ARP_I_SWITCH_2];
+		= abufs.inputs[vindex][ARP_I_SWITCH_2];
 	audiomain->palette[(*baudio->sound[10]).index]->specs->io[2].buf
-		= abufs.inputs[voice->index][ARP_I_SWITCHCLK];
+		= abufs.inputs[vindex][ARP_I_SWITCHCLK];
 	audiomain->palette[(*baudio->sound[10]).index]->specs->io[3].buf
-		= abufs.outputs[voice->index][ARP_O_SWITCH];
+		= abufs.outputs[vindex][ARP_O_SWITCH];
 	(*baudio->sound[10]).operate(
 		(audiomain->palette)[21],
 		voice,
 		(*baudio->sound[10]).param,
-		voice->locals[voice->index][10]);
+		voice->locals[vindex][10]);
 /* */
 
 /* Mixer */
-	bufmerge(abufs.inputs[voice->index][ARP_I_FILT_RM],
+	bufmerge(abufs.inputs[vindex][ARP_I_FILT_RM],
 		abufs.gains[ARP_I_FILT_RM] * 96.0, mixbuf, 0.0, sc);
-	bufmerge(abufs.inputs[voice->index][ARP_I_FILT_1SQR],
+	bufmerge(abufs.inputs[vindex][ARP_I_FILT_1SQR],
 		abufs.gains[ARP_I_FILT_1SQR] * 96.0, mixbuf, 1.0, sc);
-	bufmerge(abufs.inputs[voice->index][ARP_I_FILT_2SQR],
+	bufmerge(abufs.inputs[vindex][ARP_I_FILT_2SQR],
 		abufs.gains[ARP_I_FILT_2SQR] * 96.0, mixbuf, 1.0, sc);
-	bufmerge(abufs.inputs[voice->index][ARP_I_FILT_3TRI],
+	bufmerge(abufs.inputs[vindex][ARP_I_FILT_3TRI],
 		abufs.gains[ARP_I_FILT_3TRI] * 96.0, mixbuf, 1.0, sc);
-	bufmerge(abufs.inputs[voice->index][ARP_I_FILT_NSE],
+	bufmerge(abufs.inputs[vindex][ARP_I_FILT_NSE],
 		abufs.gains[ARP_I_FILT_NSE] * 48.0, mixbuf, 1.0, sc);
 /* */
 
@@ -884,12 +878,12 @@ bristolVoice *voice, register float *startbuf)
 	audiomain->palette[(*baudio->sound[3]).index]->specs->io[0].buf = mixbuf;
 	audiomain->palette[(*baudio->sound[3]).index]->specs->io[1].buf = scratch;
 	audiomain->palette[(*baudio->sound[3]).index]->specs->io[2].buf
-		= abufs.outputs[voice->index][ARP_O_VCF];
+		= abufs.outputs[vindex][ARP_O_VCF];
 
 	/*
 	 * Fill the KBD_CV now with a linear value related to the MIDI key number.
 	 */
-	b = abufs.outputs[voice->index][ARP_O_KBD_CV];
+	b = abufs.outputs[vindex][ARP_O_KBD_CV];
 	g = abufs.gains[ARP_I_FILT_KBD] * voice->cfreq * 1024 / baudio->samplerate;
 //printf("gain is %f %f %f\n", g, voice->cfreq, abufs.gains[ARP_I_FILT_KBD]);
 	for (i = 0; i < sc; i+=8)
@@ -904,24 +898,24 @@ bristolVoice *voice, register float *startbuf)
 		*b++ = g;
 	}
 
-	bufmerge(abufs.inputs[voice->index][ARP_I_FILT_KBD],
+	bufmerge(abufs.inputs[vindex][ARP_I_FILT_KBD],
 		abufs.gains[ARP_I_FILT_KBD], scratch, 0.0, sc);
-	bufmerge(abufs.inputs[voice->index][ARP_I_FILT_ADSR],
+	bufmerge(abufs.inputs[vindex][ARP_I_FILT_ADSR],
 		abufs.gains[ARP_I_FILT_ADSR] * 0.25, scratch, 1.0, sc);
-	bufmerge(abufs.inputs[voice->index][ARP_I_FILT_2SIN],
+	bufmerge(abufs.inputs[vindex][ARP_I_FILT_2SIN],
 		abufs.gains[ARP_I_FILT_2SIN] * 0.25, scratch, 1.0, sc);
 
-	bristolbzero(abufs.outputs[voice->index][ARP_O_VCF], ss);
+	bristolbzero(abufs.outputs[vindex][ARP_O_VCF], ss);
 
 	(*baudio->sound[3]).operate(
 		(audiomain->palette)[B_FILTER2],
 		voice,
 		(*baudio->sound[3]).param,
-		voice->locals[voice->index][3]);
+		voice->locals[vindex][3]);
 
 	/* Need to normalise the filter output again */
-	bufmerge(abufs.outputs[voice->index][ARP_O_VCF], 0.016,
-		abufs.outputs[voice->index][ARP_O_VCF], 0.0, sc);
+	bufmerge(abufs.outputs[vindex][ARP_O_VCF], 0.016,
+		abufs.outputs[vindex][ARP_O_VCF], 0.0, sc);
 /*
  * If the filter is taken back through another device, probably unlikely but 
  * very possible, the front end gain from the mixer will result in very strong
@@ -935,31 +929,31 @@ bristolVoice *voice, register float *startbuf)
 	audiomain->palette[(*baudio->sound[5]).index]->specs->io[1].buf
 		= scratch;
 	audiomain->palette[(*baudio->sound[5]).index]->specs->io[2].buf
-		= abufs.outputs[voice->index][ARP_O_VCA];
+		= abufs.outputs[vindex][ARP_O_VCA];
 
-	bufmerge(abufs.inputs[voice->index][ARP_I_VCA_VCF],
+	bufmerge(abufs.inputs[vindex][ARP_I_VCA_VCF],
 		abufs.gains[ARP_I_VCA_VCF], mixbuf, 0.0, sc);
-	bufmerge(abufs.inputs[voice->index][ARP_I_VCA_RM],
+	bufmerge(abufs.inputs[vindex][ARP_I_VCA_RM],
 		abufs.gains[ARP_I_VCA_RM], mixbuf, 1.0, sc);
 
-	bufmerge(abufs.inputs[voice->index][ARP_I_VCA_AR],
+	bufmerge(abufs.inputs[vindex][ARP_I_VCA_AR],
 		abufs.gains[ARP_I_VCA_AR], scratch, 0.0, sc);
-	bufmerge(abufs.inputs[voice->index][ARP_I_VCA_ADSR],
+	bufmerge(abufs.inputs[vindex][ARP_I_VCA_ADSR],
 		abufs.gains[ARP_I_VCA_ADSR], scratch, 1.0, sc);
 
 	bufadd(scratch, mods->initialvolume, audiomain->samplecount);
 
-	bristolbzero(abufs.outputs[voice->index][ARP_O_VCA], ss);
+	bristolbzero(abufs.outputs[vindex][ARP_O_VCA], ss);
 
 	(*baudio->sound[5]).operate(
 		(audiomain->palette)[2],
 		voice,
 		(*baudio->sound[5]).param,
-		voice->locals[voice->index][5]);
+		voice->locals[vindex][5]);
 
 	/* Need to normalise the amp output again */
-	bufmerge(abufs.outputs[voice->index][ARP_O_VCA], 0.07,
-		abufs.outputs[voice->index][ARP_O_VCA], 0.0, sc);
+	bufmerge(abufs.outputs[vindex][ARP_O_VCA], 0.07,
+		abufs.outputs[vindex][ARP_O_VCA], 0.0, sc);
 /* AMP OVER */
 
 /* Mixer */
@@ -977,11 +971,11 @@ bristolVoice *voice, register float *startbuf)
 	 *	Chorus input.
 	 */
 	bufmerge(
-		abufs.inputs[voice->index][ARP_I_MIX_VCF], abufs.gains[ARP_I_MIX_VCF],
-		abufs.outputs[voice->index][ARP_O_MIX_OUT1], 0.0, sc);
+		abufs.inputs[vindex][ARP_I_MIX_VCF], abufs.gains[ARP_I_MIX_VCF],
+		abufs.outputs[vindex][ARP_O_MIX_OUT1], 0.0, sc);
 	bufmerge(
-		abufs.inputs[voice->index][ARP_I_MIX_VCA], abufs.gains[ARP_I_MIX_VCA],
-		abufs.outputs[voice->index][ARP_O_MIX_OUT2], 0.0, sc);
+		abufs.inputs[vindex][ARP_I_MIX_VCA], abufs.gains[ARP_I_MIX_VCA],
+		abufs.outputs[vindex][ARP_O_MIX_OUT2], 0.0, sc);
 
 	/*
 	 * Pan should take an alternative input, so we should premix into a shared
@@ -989,34 +983,34 @@ bristolVoice *voice, register float *startbuf)
 	 * independently so that they can be rerouted.
 	 */
 	bufmerge(
-		abufs.outputs[voice->index][ARP_O_MIX_OUT1], 1.0,
-		abufs.outputs[voice->index][ARP_O_MIXER], 0.0, sc);
+		abufs.outputs[vindex][ARP_O_MIX_OUT1], 1.0,
+		abufs.outputs[vindex][ARP_O_MIXER], 0.0, sc);
 	bufmerge(
-		abufs.outputs[voice->index][ARP_O_MIX_OUT2], 1.0,
-		abufs.outputs[voice->index][ARP_O_MIXER], 1.0, sc);
+		abufs.outputs[vindex][ARP_O_MIX_OUT2], 1.0,
+		abufs.outputs[vindex][ARP_O_MIXER], 1.0, sc);
 
 	/*
 	 * These are the separate L/R inputs. They are collapsed between all voices
 	 * and then mixed into the stereo output in PostOps.
 	 * At this point there is not remixing possible - collapse the outputs.
 	 */
-	if (voice->index != 0)
+	if (vindex != 0)
 	{
 		/*
 		 * The only way I can see to get this through would be to 'steal' the
 		 * next available pan buffer as we only use one anyway.
 		 */
 		bufmerge(
-			abufs.inputs[voice->index][ARP_I_LEFT_IN], 128.0,
+			abufs.inputs[vindex][ARP_I_LEFT_IN], 128.0,
 			abufs.outputs[1][ARP_O_PAN], 1.0, sc);
 		bufmerge(
-			abufs.inputs[voice->index][ARP_I_RIGHT_IN], 128.0,
+			abufs.inputs[vindex][ARP_I_RIGHT_IN], 128.0,
 			abufs.outputs[2][ARP_O_PAN], 1.0, sc);
 		bufmerge(
-			abufs.inputs[voice->index][ARP_I_PAN], 1.0,
+			abufs.inputs[vindex][ARP_I_PAN], 1.0,
 			abufs.outputs[0][ARP_O_PAN], 1.0, sc);
 		bufmerge(
-			abufs.inputs[voice->index][ARP_I_MIX_FX], 1.0,
+			abufs.inputs[vindex][ARP_I_MIX_FX], 1.0,
 			baudio->leftbuf, 1.0, sc);
 	}
 /* */
@@ -1034,7 +1028,7 @@ bristolVoice *voice, register float *startbuf)
 		{
 			//bristolbzero(audiomain->io_o[0], audiomain->segmentsize);
 			bufmerge(
-				abufs.inputs[voice->index][ARP_I_OUT_1], 0.0833f,
+				abufs.inputs[vindex][ARP_I_OUT_1], 0.0833f,
 				audiomain->io_o[0], 1.0f, //4.0 * audiomain->m_io_igc,
 				audiomain->samplecount);
 		}
@@ -1043,14 +1037,14 @@ bristolVoice *voice, register float *startbuf)
 		{
 			//bristolbzero(audiomain->io_o[1], audiomain->segmentsize);
 			bufmerge(
-				abufs.inputs[voice->index][ARP_I_OUT_2], 0.0833f,
+				abufs.inputs[vindex][ARP_I_OUT_2], 0.0833f,
 				audiomain->io_o[1], 1.0f, //4.0 * audiomain->m_io_igc,
 				audiomain->samplecount);
 		}
 
 		if (((d = audiomain->io_o[2]) != NULL) && (audiomain->iocount > 2))
 		{
-			s = abufs.inputs[voice->index][ARP_I_OUT_3];
+			s = abufs.inputs[vindex][ARP_I_OUT_3];
 			//bristolbzero(d, audiomain->segmentsize);
 
 			/* Third IO will be DC */
@@ -1069,7 +1063,7 @@ bristolVoice *voice, register float *startbuf)
 
 		if (((d = audiomain->io_o[3]) != NULL) && (audiomain->iocount > 3))
 		{
-			s = abufs.inputs[voice->index][ARP_I_OUT_4];
+			s = abufs.inputs[vindex][ARP_I_OUT_4];
 			//bristolbzero(d, audiomain->segmentsize);
 
 			/* Fourth IO will be DC */
