@@ -1,7 +1,7 @@
 
 /*
  *  Diverse Bristol audio routines.
- *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2011
+ *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2012
  *
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -66,7 +66,7 @@ int
 junoController(Baudio *baudio, u_char operator,
 u_char controller, float value)
 {
-	int tval = value * CONTROLLER_RANGE;
+	int tval = value * C_RANGE_MIN_1;
 
 #ifdef DEBUG
 	printf("bristolJunoControl(%i, %i, %f)\n", operator, controller, value);
@@ -79,17 +79,52 @@ u_char controller, float value)
 	{
 		switch (tval) {
 			case 0:
+				baudio->effect[0]->param->param[0].float_val = 0.2;
+				baudio->effect[0]->param->param[1].float_val = 0.2;
+				baudio->effect[0]->param->param[2].float_val = 0.2;
 				baudio->effect[0]->param->param[3].float_val = 0.0;
 				break;
-			default:
-				baudio->effect[0]->param->param[0].float_val =
-					((float) tval) / 12;
-				baudio->effect[0]->param->param[1].float_val =
-					((float) tval) / 12;
-				baudio->effect[0]->param->param[2].float_val =
-					((float) tval) / 12;
-				baudio->effect[0]->param->param[3].float_val =
-					((float) tval) / 12;
+			case 1:
+				baudio->effect[0]->param->param[0].float_val = 0.005;
+				baudio->effect[0]->param->param[1].float_val = 0.0168;
+				baudio->effect[0]->param->param[2].float_val = 0.02;
+				baudio->effect[0]->param->param[3].float_val = 0.65;
+				break;
+			case 2:
+				baudio->effect[0]->param->param[0].float_val = 0.008;
+				baudio->effect[0]->param->param[1].float_val = 0.016;
+				baudio->effect[0]->param->param[2].float_val = 0.070;
+				baudio->effect[0]->param->param[3].float_val = 0.65;
+				break;
+			case 3:
+				baudio->effect[0]->param->param[0].float_val = 0.015;
+				baudio->effect[0]->param->param[1].float_val = 0.015;
+				baudio->effect[0]->param->param[2].float_val = 0.2;
+				baudio->effect[0]->param->param[3].float_val = 0.65;
+				break;
+			case 4:
+				baudio->effect[0]->param->param[0].float_val = 0.030;
+				baudio->effect[0]->param->param[1].float_val = 0.014;
+				baudio->effect[0]->param->param[2].float_val = 0.3;
+				baudio->effect[0]->param->param[3].float_val = 0.65;
+				break;
+			case 5:
+				baudio->effect[0]->param->param[0].float_val = 0.1;
+				baudio->effect[0]->param->param[1].float_val = 0.013;
+				baudio->effect[0]->param->param[2].float_val = 0.4;
+				baudio->effect[0]->param->param[3].float_val = 0.65;
+				break;
+			case 6:
+				baudio->effect[0]->param->param[0].float_val = 0.02;
+				baudio->effect[0]->param->param[1].float_val = 0.012;
+				baudio->effect[0]->param->param[2].float_val = 0.5;
+				baudio->effect[0]->param->param[3].float_val = 0.75;
+				break;
+			case 7:
+				baudio->effect[0]->param->param[0].float_val = 0.333;
+				baudio->effect[0]->param->param[1].float_val = 0.011;
+				baudio->effect[0]->param->param[2].float_val = 0.62;
+				baudio->effect[0]->param->param[3].float_val = 0.75;
 				break;
 		}
 		return(0);
