@@ -1,7 +1,7 @@
 
 /*
  *  Diverse Bristol audio routines.
- *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2011
+ *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2012
  *
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -69,13 +69,16 @@ memorymoogController(Baudio *baudio, u_char operator, u_char controller, float v
 	 */
 	if (operator == 100)
 	{
-		if (controller == 0) {
-			baudio->effect[0]->param->param[0].float_val = value;
-			return(0);
+		if (controller == 1) {
+			baudio->effect[0]->param->param[3].float_val = value;
+		} else {
+			value *= 0.2;
+			baudio->effect[0]->param->param[0].float_val = 
+				(0.1 + value * 20) * 1024 / baudio->samplerate;
+			baudio->effect[0]->param->param[1].float_val = value;
+			baudio->effect[0]->param->param[2].float_val = value;
 		}
-		baudio->effect[0]->param->param[1].float_val = value;
-		baudio->effect[0]->param->param[2].float_val = value;
-		baudio->effect[0]->param->param[3].float_val = value;
+		return(0);
 	}
 
 	if (operator != 126)
@@ -272,6 +275,11 @@ memorymoogController(Baudio *baudio, u_char operator, u_char controller, float v
 			else
 				baudio->mixflags &= ~MMOOG_PEDAL_OSC2;
 			break;
+		case 47:
+			baudio->midi_pitch = value * 12;
+			doPitchWheel(baudio);
+			alterAllNotes(baudio); 
+			break;
 	}
 	return(0);
 }
