@@ -1,7 +1,7 @@
 
 /*
  *  Diverse Bristol audio routines.
- *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2011
+ *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2012
  *
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -55,14 +55,14 @@ poly6Controller(Baudio *baudio, u_char operator, u_char controller, float value)
 	 */
 	if (operator == 100)
 	{
-		float oval = value * CONTROLLER_RANGE / 3;
-
 		if (controller == 1) {
-			baudio->effect[0]->param->param[0].float_val = value;
-			baudio->effect[0]->param->param[2].float_val = value;
+			baudio->effect[0]->param->param[3].float_val = value;
 		} else if (controller == 0) {
-			baudio->effect[0]->param->param[1].float_val = oval;
-			baudio->effect[0]->param->param[3].float_val = oval;
+			value = 0.1 + value * C_RANGE_MIN_1 / 3 * 0.9;
+			baudio->effect[0]->param->param[0].float_val =
+				(0.1 + (value * value) * 8) * 1024 / baudio->samplerate;
+			baudio->effect[0]->param->param[2].float_val = value * 0.2;
+			baudio->effect[0]->param->param[1].float_val = value * 0.2;
 		}
 	}
 
