@@ -1,7 +1,7 @@
 
 /*
  *  Diverse Bristol audio routines.
- *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2011
+ *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2012
  *
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -52,7 +52,8 @@ poly800Controller(Baudio *baudio, u_char operator, u_char controller, float valu
 
 		switch (controller) {
 			case 0:
-				baudio->effect[0]->param->param[0].float_val = value * value;
+				baudio->effect[0]->param->param[controller].float_val = value;
+					(0.1 + (value * value) * 20) * 1024 / baudio->samplerate;
 				break;
 			case 1:
 			case 2:
