@@ -1,7 +1,7 @@
 
 /*
  *  Diverse Bristol audio routines.
- *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2011
+ *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2012
  *
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -204,16 +204,17 @@ float value)
 			 * reach 0 to the depth, and has to be adjusted such that the 
 			 * speed is constant over all depths.
 			 */
-			baudio->effect[0]->param->param[0].float_val = value * value;
+			baudio->effect[0]->param->param[0].float_val =
+				(0.1 + (value * value) * 20) * 1024 / baudio->samplerate;
 			break;
 		case 31:
-			baudio->effect[0]->param->param[1].float_val = value;
+			baudio->effect[0]->param->param[1].float_val = (value * value);
 			break;
 		case 32:
-			baudio->effect[0]->param->param[2].float_val = value;
+			baudio->effect[0]->param->param[2].float_val = (value * value);
 			break;
 		case 33:
-			baudio->effect[0]->param->param[3].float_val = value;
+			baudio->effect[0]->param->param[3].float_val = (value * value);
 			break;
 		case 34:
 			((pmods *) baudio->mixlocals)->pan = value;
