@@ -1,7 +1,7 @@
 
 /*
  *  Diverse Bristol audio routines.
- *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2011
+ *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2012
  *
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -191,6 +191,17 @@ float value)
 			else
 				baudio->mixflags |= P1_LFO_SQR;
 			break;
+		case 27:
+			if (ivalue == 0)
+				baudio->mixflags &= ~BRISTOL_MULTITRIG;
+			else
+				baudio->mixflags |= BRISTOL_MULTITRIG;
+		case 28:
+			if (ivalue == 0)
+				baudio->mixflags &= ~P1_DRONE;
+			else
+				baudio->mixflags |= P1_DRONE;
+			break;
 	}
 	return(0);
 }
@@ -288,6 +299,11 @@ bristolVoice *voice, register float *startbuf)
 		voice->locals[voice->index][7]);
 /* NOISE OVER */
 
+	if ((baudio->mixflags & BRISTOL_MULTITRIG) == 0)
+		voice->flags &= ~BRISTOL_KEYREON;
+	if (baudio->mixflags & P1_DRONE)
+		voice->flags &= ~BRISTOL_KEYOFF;
+
 /* ADSR - POLY MOD */
 	/*
 	 * Run the ADSR for the filter, reusing the startbuf. We need this for the
@@ -523,6 +539,7 @@ bristolVoice *voice, register float *startbuf)
 		voice,
 		(*baudio->sound[6]).param,
 		voice->locals[voice->index][6]);
+
 /* FINAL STAGE - DONE */
 	return(0);
 }
