@@ -1,7 +1,7 @@
 
 /*
  *  Diverse Bristol audio routines.
- *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2011
+ *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2012
  *
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -260,7 +260,7 @@ static int operate(bristolOP *operator,
 				memset(ws, 0, DCO_WAVE_SZE * sizeof(float));
 				generateBLOwaveformF(voice->cFreq*transp, &ws[0], BLO_SAW);
 
-				for (obp = 0; obp < count; obp++)
+				for (obp = 0; obp < 1024; obp++)
 					wt[obp] = (ws[obp] + ws[(obp * 2) & 1023]) * 0.5;
 
 				break;
