@@ -1,7 +1,7 @@
 
 /*
  *  Diverse Bristol audio routines.
- *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2011
+ *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2012
  *
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -62,12 +62,25 @@ static int param(param, value)
 static int param(bristolOP *operator, bristolOPParams *param,
 	unsigned char index, float value)
 {
+	bristolVCHORUS *specs;
+
+	specs = (bristolVCHORUS *) operator->specs;
+
 #ifdef DEBUG
 	printf("checkParams(%f)\n", value);
 #endif
 
 	switch (index) {
 		case 0:
+			/*
+			 * We want to go from 0.1Hz up to perhaps 20Hz. That means we need
+			 * to step through the 1024 sinewave table at that rate.
+			 *
+			 * specs->samplerate
+			 */
+			param->param[index].float_val = 
+				(0.1 + value * 20) * 1024 / specs->samplerate;
+			return(0);
 		case 1:
 			if ((param->param[index].int_val = value * 256) <= 0)
 				param->param[index].int_val = 1;
@@ -83,11 +96,15 @@ static int param(bristolOP *operator, bristolOPParams *param,
 	return(0);
 }
 
+static float sinewave[1024];
+
 /*
  * Reset any local memory information.
  */
 static int reset(bristolOP *operator, bristolOPParams *param)
 {
+	int i;
+
 #ifdef BRISTOL_DBG
 	printf("reset(%x)\n", operator);
 #endif
@@ -100,6 +117,11 @@ static int reset(bristolOP *operator, bristolOPParams *param)
 	param->param[0].int_val = 10;
 	param->param[1].int_val = 10;
 	param->param[2].int_val = 0;
+
+	// Get a normalised sinewave.
+	for (i = 0; i < 1024; i++)
+		sinewave[i] = sinf(M_PI * ((float) i) * 2.0 / 1024.0f) + 1.0;
+
 	return(0);
 }
 
@@ -154,7 +176,8 @@ static int operate(bristolOP *operator,
 	 * calculated as 441000 samples, so we divide speed by depth * 44100;
 	 */
 	depth = param->param[DEPTH].float_val * 1024;
-	speed = param->param[SPEED].float_val * 0.0002 * depth;
+	speed = param->param[SPEED].float_val;
+
 	/*
 	 * Let scan be ten seconds to reach gain
 	 */
@@ -244,7 +267,6 @@ static int operate(bristolOP *operator,
 		 * Adjust the scan rate through memory. Initially out is zero, and we
 		 * tend it towards depth by adding the speed increments. When we reach
 		 * depth we change the direction.
-		 */
 		if (fdir == 0)
 		{
 			if ((scanp += speed) > depth)
@@ -253,6 +275,10 @@ static int operate(bristolOP *operator,
 			if ((scanp -= speed) < speed)
 				fdir = 0;
 		}
+		 */
+		if ((scanr += speed) >= 1024)
+			scanr -= 1024;
+		scanp = sinewave[(int) scanr] * depth;
 	}
 
 	local->Histin = histin;
@@ -300,6 +326,7 @@ chorusinit(bristolOP **operator, int index, int samplerate, int samplecount)
 	(*operator)->param= param;
 
 	specs = (bristolVCHORUS *) bristolmalloc0(sizeof(bristolVCHORUS));
+	specs->samplerate = samplerate;
 	(*operator)->specs = (bristolOPSpec *) specs;
 	(*operator)->size = sizeof(bristolVCHORUS);
 
