@@ -1,7 +1,7 @@
 
 /*
  *  Diverse Bristol audio routines.
- *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2011
+ *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2012
  *
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -218,7 +218,7 @@ static int operate(register bristolOP *operator, bristolVoice *voice,
 		if (param->param[8].float_val == 0.0)
 			//attack = gainTable[
 			//	(int) (C_RANGE_MIN_1 * param->param[0].float_val)].rate;
-			attack = 12.0 / (8.0 + specs->duration * specs->samplerate
+			attack = 12.0 / (specs->samplerate * 0.0005 + specs->duration * specs->samplerate
 				* param->param[0].float_val
 				* param->param[0].float_val
 				* param->param[0].float_val);
@@ -236,7 +236,7 @@ static int operate(register bristolOP *operator, bristolVoice *voice,
 			attack = param->param[0].float_val * MM_PARAM;
 			attack = gainTable[(int) (attack * C_RANGE_MIN_1 + 1)].rate;
 			 */
-			attack = 12.0 / (8.0 + specs->duration * specs->samplerate
+			attack = 12.0 / (specs->samplerate * 0.0005 + specs->duration * specs->samplerate
 				* param->param[0].float_val * MM_PARAM);
 	} else {
 		if (param->param[8].float_val == 0.0)
