@@ -1,7 +1,7 @@
 
 /*
  *  Diverse Bristol audio routines.
- *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2011
+ *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2012
  *
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -260,7 +260,6 @@ param(bristolOP *operator, bristolOPParams *param,
 			else
 				param->param[index].int_val = 0;
 			param->param[index].float_val = value;
-//printf("KBD: %f\n", value);
 			break;
 		case 4:
 			/* See if we are trying to avoid Huovilainen filters */
@@ -580,7 +579,7 @@ static int operate(register bristolOP *operator, bristolVoice *voice,
 		float coff;
 
 		float resonance = param->param[1].float_val;
-		Mod = param->param[2].float_val * param->param[2].float_val * 0.002;
+		Mod = param->param[2].float_val * param->param[2].float_val * 0.03;
 
 		/*
 		 * Cutoff is a power curve for better control at lower frequencies and
@@ -604,8 +603,14 @@ static int operate(register bristolOP *operator, bristolVoice *voice,
 			* 20000 / srate
 				+
 			param->param[3].float_val * 4 * voice->cfreq / srate;
-		 */
 		coff = getcoff(param->param[0].float_val, param->param[3].float_val);
+		 */
+		if (param->param[3].float_val == 0)
+			coff = param->param[0].float_val * param->param[0].float_val
+				* 20000 / srate;
+		else
+			coff = param->param[3].float_val * param->param[0].float_val
+				* 4 * voice->cfreq / srate;
 
 		 /*
 		if (param->param[3].int_val == 0)
@@ -701,7 +706,7 @@ static int operate(register bristolOP *operator, bristolVoice *voice,
 		float coff;
 
 		float resonance = param->param[1].float_val;
-		Mod = param->param[2].float_val * param->param[2].float_val * 0.002;
+		Mod = param->param[2].float_val * param->param[2].float_val * 0.02;
 
 		/*
 		 * Cutoff is a power curve for better control at lower frequencies and
@@ -725,8 +730,14 @@ static int operate(register bristolOP *operator, bristolVoice *voice,
 			* 20000 / srate
 				+
 			param->param[3].float_val * 4 * voice->cfreq / srate;
-		 */
 		coff = getcoff(param->param[0].float_val, param->param[3].float_val);
+		 */
+		if (param->param[3].float_val == 0)
+			coff = param->param[0].float_val * param->param[0].float_val
+				* 20000 / srate;
+		else
+			coff = param->param[3].float_val * param->param[0].float_val
+				* 4 * voice->cfreq / srate;
 
 		 /*
 		if (param->param[3].int_val == 0)
