@@ -1,7 +1,7 @@
 
 /*
  *  Diverse Bristol audio routines.
- *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2011
+ *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2012
  *
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -65,7 +65,9 @@ int ftap[32]= {4,5,5,6,6,7,7,8,8,7,7,6,6,5,5,4,4,5,5,6,6,7,7,8,8,7,7,6,6,5,5,4};
 
 int ztap[32]= {7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7};
 
-int *tap1, *tap2, *tap3, *tap4, *tap5, *tap6;
+//int *tap1, *tap2, *tap3, *tap4, *tap5, *tap6;
+int *tap1 = NULL, *tap2 = NULL, *tap3 = NULL;
+int *tap4 = NULL, *tap5 = NULL, *tap6 = NULL;
 
 //float tapgain[TAPS] = {1.5, 2, 2.5, 3.0, 3.5, 4, 4.5, 5, 5.5};
 /* As the filtering goes up the signal gain goes down, so a small correction */
@@ -360,7 +362,7 @@ static int operate(bristolOP *operator,
 #endif
 
 	tap = local->ctap;
-	phase = local->phase;
+	phase = &local->phase[0];
 	tcount = local->tcount;
 	g1 = local->g1;
 	g2 = local->g2;
@@ -369,8 +371,11 @@ static int operate(bristolOP *operator,
 	g5 = local->g5;
 	g6 = local->g6;
 
-/*printf("hammondchorus(%i, %1.2f, %i): %i, %i\n", */
-/*rate, lag, chorus, tcount, tap); */
+	if (tap1 == NULL)
+		return(0);
+
+//printf("hammondchorus(%i, %i): %i, %i\n",
+//rate, chorus, tcount, tap);
 
 	/*
 	 * We now need to take the input signal and separate it out into several
@@ -440,6 +445,8 @@ static int operate(bristolOP *operator,
 				+ phase[tap2[tap]].out * upgain[tcount] * g2) * 0.7f;
 		}
 
+//		*dest++ = *source;
+
 		ph = *(source++);
 	}
 
