@@ -1,7 +1,7 @@
 
 /*
  *  Diverse Bristol audio routines.
- *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2011
+ *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2012
  *
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -391,7 +391,10 @@ midiThread(audioMain *audiomain)
 	audiomain->mtStatus = BRISTOL_OK;
 
 #ifndef BRISTOL_SEMAPHORE
-	bristolMidiRegisterForwarder(midiMsgForwarder);
+	if (audiomain->flags & BRISTOL_JACK_DUAL)
+		bristolMidiRegisterForwarder(NULL);
+	else
+		bristolMidiRegisterForwarder(midiMsgForwarder);
 #endif
 
 	/*
