@@ -1,7 +1,7 @@
 
 /*
  *  Diverse Bristol audio routines.
- *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2011
+ *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2012
  *
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -26,6 +26,7 @@
 
 #include "brightondevflags.h"
 #include "brightonevents.h"
+#include "brightonvectorgraphics.h"
 
 #define BRIGHTON_ST_CLOCK	0
 #define BRIGHTON_ST_REQ		1
@@ -44,6 +45,8 @@
 
 #define isblue(x,y,z) \
 			((x >= 0) && \
+			(y != NULL) && \
+			(z != NULL) && \
 			((z[x] < 0) || \
 			((y[z[x]].red == 0) && \
 			(y[z[x]].green == 0) && \
