@@ -1,7 +1,7 @@
 
 /*
  *  Diverse Bristol midi routines.
- *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2011
+ *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2012
  *
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -82,7 +82,6 @@ void *param)
 
 	if (bmidi.flags & BRISTOL_BMIDI_DEBUG)
 		printf("bristolMidiOpen(%s, %x)\n", dev, flags);
-printf("bristolMidiOpen(%s, %x)\n", dev, flags);
 
 	if (dev == NULL)
 		dev = devname;
@@ -115,7 +114,7 @@ printf("bristolMidiOpen(%s, %x)\n", dev, flags);
 	if ((handle = bristolMidiFindFreeHandle()) < 0)
 		return(handle);
 
-	bmidi.msgforwarder = NULL;
+	//bmidi.msgforwarder = NULL;
 	bmidi.handle[handle].handle = handle; /* That looks kind of wierd! */
 	bmidi.handle[handle].state = BRISTOL_MIDI_OK;
 	bmidi.handle[handle].channel = chan;
@@ -547,9 +546,20 @@ bristolMidiRawWrite(int dev, bristolMidiMsg *msg, int size)
 			msg->channel,
 			size);
 
-	if (bristolPhysWrite(bmidi.dev[dev].fd,
-		(unsigned char *) &msg->command, 1) != 0)
-		return(1);
+	/*
+	 * For short messages we are going to join the channel back together. This
+	 * is not needed for SYSEX/Bristol messages.
+	 */
+	if (msg->params.bristol.msgLen < 4)
+	{
+		unsigned char ch = (msg->command & 0xf0)|msg->channel;
+
+		if (bristolPhysWrite(bmidi.dev[dev].fd, (unsigned char *) &ch, 1) != 0)
+			return(1);
+	} else
+		if (bristolPhysWrite(bmidi.dev[dev].fd,
+			(unsigned char *) &msg->command, 1) != 0)
+			return(1);
 
 	if (msg->command != MIDI_SYSEX)
 	{
